==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/sk.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logovanie",
    "Errors in the log" : "Chyby v protokole",
    "Failed to get an iterator for log entries: %s" : "Nepodarilo sa získať iterátor pre položky denníka: %s",
    "No errors in the logs since %s" : "Žiadne chyby v protokole od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n chyba v protokole od %s","%n chyby v protokole od %s","%n chýb v protokole od %s","%n chýb v protokole od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n varovanie v protokole od %s","%n varovania v protokole od %s","%n varovaní v protokole od %s","%n varovaní v protokole od %s"],
    "Log Reader" : "Čítačka logov",
    "A log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Log reader" : "Čítačka logov",
    "Open log reader settings" : "Otvoriť nastavenia čítačky protokolu",
    "Log reader settings" : "Nastavenia čítačky protokolu",
    "Currently the log file {file} is shown" : "V súčasnosti je zobrazený súbor protokolu {file}",
    "Show server log" : "Zobraziť protokol serveru",
    "Live view is disabled" : "Živé zobrazenie je vypnuté",
    "No log file" : "Žiadny súbor protokolu",
    "File-based logging must be enabled to access logs from the Web UI." : "Na prístup k protokolom z webového užívateľského rozhrania musí byť povolené protokolovanie založené na súboroch.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Ak sa domnievate, že ide o chybu, overte {setting} vo svojom {config} a pozrite si príručku správy Nextcloud.",
    "Level" : "Úroveň",
    "App" : "Aplikácia",
    "No app in context" : "Žiadna aplikácia v kontexte",
    "Time" : "Čas",
    "Copy raw entry" : "Skopírovať nespracovaný záznam",
    "Copy formatted entry" : "Kopírovať formátovanú položku",
    "Hide exception details" : "Skryť podrobnosti o výnimke",
    "View exception details" : "Zobraziť podrobnosti o výnimke",
    "Raw log entry" : "Nespracovaný záznam protokolu",
    "Log entry successfully copied" : "Záznam protokolu bol úspešne skopírovaný",
    "Search log entries" : "Hľadať položky denníka",
    "Caused by {exception}" : "Spôsobené {exception}",
    "Line {line}" : "Riadok {line}",
    "Filter log levels" : "Filtrovať úrovne protokolu",
    "Set log level" : "Nastaviť úroveň protokolu",
    "Time format" : "Formát času",
    "Live view" : "Živý náhľad",
    "Download/Upload logs" : "Stiahnuť/Nahrať protokoly",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Záznamy protokolu skopírované zo schránky môžete zobraziť aj tak, že ich prilepíte do zobrazenia protokolu pomocou: {keyboardShortcut}",
    "Download logs" : "Prevziať logy",
    "Show local log file" : "Zobraziť lokálny súbor protokolu",
    "Upload local log file to be displayed" : "Nahrať lokálny súbor protokolu pre zobrazenie",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nepodarilo sa prečítať lokálny súbor protokolu",
    "Raw data" : "Nespracované dáta",
    "Local time" : "Miestny čas",
    "UTC time" : "Čas UTC",
    "Relative" : "Relatívny",
    "Time format used for displaying the timestamp" : "Formát času používaný pre zobrazenie časovej pečiatky",
    "(Local log files only support the \"raw\" time format)" : "(Lokálne súbory protokolu podporujú iba „nespracovaný“ formát času)",
    "Could not change date time format." : "Nemožno zmeniť formát dátumu a času.",
    "Polling is disabled because server is not configured to log to file" : "Dopytovanie je zakázané, pretože server nie je nakonfigurovaný na prihlásenie do súboru",
    "Polling (live view)" : "Dopytovanie (živé zobrazenie)",
    "Could not change live view setting." : "Nepodarilo sa zmeniť nastavenie živého náhľadu.",
    "Filter logging levels" : "Filtrovať úrovne záznamu do protokolu",
    "Could not set logging levels to show" : "Nepodarilo sa nastaviť úroveň logovania pre zobrazenie",
    "Set backend loglevel" : "Nastaviť úroveň logovania backendu",
    "Could not set logging level" : "Nepodarilo sa nastaviť úroveň logovania",
    "Application" : "Aplikácia",
    "Message" : "Správa",
    "Log entry actions" : "Akcie záznamu protokolu",
    "Loading older log entries" : "Načítavam staršie záznamy protokolu",
    "No older log entries available" : "Žiadne staršie záznamy protokolu nie sú dostupné",
    "Collapse row" : "Zbaliť riadok",
    "Expand row" : "Rozbaliť riadok",
    "Show details" : "Zobraziť podrobnosti",
    "Debug" : "Ladenie",
    "Info" : "Info",
    "Warning" : "Varovanie",
    "Error" : "Chyba",
    "Fatal" : "Fatálne",
    "Could not load log entries" : "Nepodarilo sa načítať záznamy protokolu",
    "Clipboard" : "Schránka",
    "Could not parse clipboard content" : "Nepodarilo sa prečítať obsah schránky",
    "Could not fetch new log entries (server unavailable)" : "Nepodarilo sa načítať nové záznamy protokolu (server nedostupný)",
    "Could not fetch new entries" : "Nepodarilo sa načítať nové záznamy",
    "Could not copy to clipboard, please copy manually:" : "Nepodarilo sa skopírovať zo schránky, prosím skopírujte manuálne:",
    "\tfrom {address} by {user} at {time}\n" : "\tod {address} užívateľom {user} o {time}\n"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/logreader/l10n/sk.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logovanie",
    "Errors in the log" : "Chyby v protokole",
    "Failed to get an iterator for log entries: %s" : "Nepodarilo sa získať iterátor pre položky denníka: %s",
    "No errors in the logs since %s" : "Žiadne chyby v protokole od %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n chyba v protokole od %s","%n chyby v protokole od %s","%n chýb v protokole od %s","%n chýb v protokole od %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n varovanie v protokole od %s","%n varovania v protokole od %s","%n varovaní v protokole od %s","%n varovaní v protokole od %s"],
    "Log Reader" : "Čítačka logov",
    "A log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Log reader" : "Čítačka logov",
    "Open log reader settings" : "Otvoriť nastavenia čítačky protokolu",
    "Log reader settings" : "Nastavenia čítačky protokolu",
    "Currently the log file {file} is shown" : "V súčasnosti je zobrazený súbor protokolu {file}",
    "Show server log" : "Zobraziť protokol serveru",
    "Live view is disabled" : "Živé zobrazenie je vypnuté",
    "No log file" : "Žiadny súbor protokolu",
    "File-based logging must be enabled to access logs from the Web UI." : "Na prístup k protokolom z webového užívateľského rozhrania musí byť povolené protokolovanie založené na súboroch.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Ak sa domnievate, že ide o chybu, overte {setting} vo svojom {config} a pozrite si príručku správy Nextcloud.",
    "Level" : "Úroveň",
    "App" : "Aplikácia",
    "No app in context" : "Žiadna aplikácia v kontexte",
    "Time" : "Čas",
    "Copy raw entry" : "Skopírovať nespracovaný záznam",
    "Copy formatted entry" : "Kopírovať formátovanú položku",
    "Hide exception details" : "Skryť podrobnosti o výnimke",
    "View exception details" : "Zobraziť podrobnosti o výnimke",
    "Raw log entry" : "Nespracovaný záznam protokolu",
    "Log entry successfully copied" : "Záznam protokolu bol úspešne skopírovaný",
    "Search log entries" : "Hľadať položky denníka",
    "Caused by {exception}" : "Spôsobené {exception}",
    "Line {line}" : "Riadok {line}",
    "Filter log levels" : "Filtrovať úrovne protokolu",
    "Set log level" : "Nastaviť úroveň protokolu",
    "Time format" : "Formát času",
    "Live view" : "Živý náhľad",
    "Download/Upload logs" : "Stiahnuť/Nahrať protokoly",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Záznamy protokolu skopírované zo schránky môžete zobraziť aj tak, že ich prilepíte do zobrazenia protokolu pomocou: {keyboardShortcut}",
    "Download logs" : "Prevziať logy",
    "Show local log file" : "Zobraziť lokálny súbor protokolu",
    "Upload local log file to be displayed" : "Nahrať lokálny súbor protokolu pre zobrazenie",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Nepodarilo sa prečítať lokálny súbor protokolu",
    "Raw data" : "Nespracované dáta",
    "Local time" : "Miestny čas",
    "UTC time" : "Čas UTC",
    "Relative" : "Relatívny",
    "Time format used for displaying the timestamp" : "Formát času používaný pre zobrazenie časovej pečiatky",
    "(Local log files only support the \"raw\" time format)" : "(Lokálne súbory protokolu podporujú iba „nespracovaný“ formát času)",
    "Could not change date time format." : "Nemožno zmeniť formát dátumu a času.",
    "Could not change live view setting." : "Nepodarilo sa zmeniť nastavenie živého náhľadu.",
    "Filter logging levels" : "Filtrovať úrovne záznamu do protokolu",
    "Application" : "Aplikácia",
    "Message" : "Správa",
    "Log entry actions" : "Akcie záznamu protokolu",
    "Loading older log entries" : "Načítavam staršie záznamy protokolu",
    "No older log entries available" : "Žiadne staršie záznamy protokolu nie sú dostupné",
    "Collapse row" : "Zbaliť riadok",
    "Expand row" : "Rozbaliť riadok",
    "Show details" : "Zobraziť podrobnosti",
    "Debug" : "Ladenie",
    "Info" : "Info",
    "Warning" : "Varovanie",
    "Error" : "Chyba",
    "Fatal" : "Fatálne",
    "Could not load log entries" : "Nepodarilo sa načítať záznamy protokolu",
    "Clipboard" : "Schránka",
    "Could not parse clipboard content" : "Nepodarilo sa prečítať obsah schránky",
    "Could not fetch new log entries (server unavailable)" : "Nepodarilo sa načítať nové záznamy protokolu (server nedostupný)",
    "Could not fetch new entries" : "Nepodarilo sa načítať nové záznamy",
    "Could not copy to clipboard, please copy manually:" : "Nepodarilo sa skopírovať zo schránky, prosím skopírujte manuálne:",
    "\tfrom {address} by {user} at {time}\n" : "\tod {address} užívateľom {user} o {time}\n",
    "line {line}" : "riadok {line}",
    "Download / Upload logs" : "Stiahnuť / Nahrať protokoly"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
